RTD Dropdown for MkDocs
=======================
[![Pypi Version][pypi-image]][pypi-link]

  [pypi-image]: http://img.shields.io/pypi/v/mkdocs-rtd-dropdown.svg
  [pypi-link]: https://pypi.python.org/pypi/mkdocs-rtd-dropdown

A ReadTheDocs theme for [MkDocs](http://www.mkdocs.org/)

![Dropdown Demo](docs/img/example.png)



Features
--------

* Based on the [MkDocs ReadTheDocs](https://github.com/mkdocs/mkdocs/tree/master/mkdocs/themes) theme
* Adds dropdown functionality to mimic ReadTheDocs

For further discussion, see [this issue](https://github.com/mkdocs/mkdocs/issues/588#issuecomment-341931422).


How to use
----------

Install ReadTheDocs Dropdown with pip:

```
pip install mkdocs-rtd-dropdown
```

Set theme to rtd-dropdown in your projects `mkdocs.yml`:

```
theme:
  name: 'rtd-dropdown'
```

Development
-----------

This theme is stable but early in development. There may be changes to how folder structures
are parsed into subdirectories in future releases.

If you discover bugs or areas for improvement please feel free to submit issues or PRs.

<!-- Basic hit-counter, helps me decide which projects to focus on -->
[![Analytics](https://cjs-beacon.appspot.com/UA-10006093-3/github/cjsheets/mkdocs-rtd-dropdown?pixel)](https://github.com/cjsheets/mkdocs-rtd-dropdown)